@@ -159,9 +159,9 @@ ciphertext.
 >>> # just a small sanity test here for doctest
 >>> import types
 >>> assert type(ciphertext) == types.StringType, \
-           "What GnuPG gave back isn't a string!"
+           "What GnuPG gave back is not a string!"
 
-Here's an example of generating a key:
+Here is an example of generating a key:
 >>> import GnuPGInterface
 >>> gnupg = GnuPGInterface.GnuPG()
 >>> gnupg.options.meta_interactive = 0
@@ -225,8 +225,8 @@ import sys
 import fcntl, FCNTL
 
 __author__   = "Frank J. Tobin, ftobin@neverending.org"
-__version__  = "0.3.0"
-__revision__ = "$Id: GnuPGInterface.py,v 1.14 2001/08/26 00:35:29 ftobin Exp $"
+__version__  = "0.3.1"
+__revision__ = "$Id: GnuPGInterface.py,v 1.17 2001/11/03 07:46:07 ftobin Exp $"
 
 # "standard" filehandles attached to processes
 _stds = [ 'stdin', 'stdout', 'stderr' ]
@@ -386,6 +386,11 @@ class GnuPG:
                       % fh_name
 
             pipe = os.pipe()
+            # fix by drt@un.bewaff.net noting
+            # that since pipes are unidirectional on some systems,
+            # so we have to 'turn the pipe around'
+            # if we are writing
+            if _fd_modes[fh_name] == 'w': pipe = (pipe[1], pipe[0])
             process._pipes[fh_name] = Pipe(pipe[0], pipe[1], 0)
         
         for fh_name, fh in attach_fhs.items():
